// Copyright (C) 2023  Benedikt Zumtobel
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published
// by the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.

package pwch

import "time"

var Cfg Config

type Config struct {
	Domain     string `yaml:"domain"`
	URLPrefix  string `yaml:"url_prefix"`
	AssetsPath string `yaml:"assets_path"`
	Server     struct {
		SocketPath string `yaml:"socket_path"`
	} `yaml:"server"`
	DB struct {
		Host     string `yaml:"host"`
		DBName   string `yaml:"db_name"`
		User     string `yaml:"user"`
		Password string `yaml:"password"`
		SSLMode  string `yaml:"ssl_mode"`
	} `yaml:"db"`
	Bcrypt struct {
		Cost int `yaml:"cost"`
	} `yaml:"bcrypt"`
	SMTP struct {
		Host          string `yaml:"host"`
		Port          string `yaml:"port"`
		LoginUser     string `yaml:"login_user"`
		LoginPassword string `yaml:"login_password"`
		Sender        string `yaml:"sender"`
	} `yaml:"smtp"`
	PasswordPolicy struct {
		MinLength   int  `yaml:"min_length"`
		MaxLength   int  `yaml:"max_length"`
		LowerCase   bool `yaml:"lower_case"`
		UpperCase   bool `yaml:"upper_case"`
		Digits      bool `yaml:"digits"`
		SepcialChar bool `yaml:"special_char"`
	} `yaml:"password_policy"`
	OTL struct {
		TokenLength int           `yaml:"token_length"`
		ValidFor    time.Duration `yaml:"valid_for"`
	} `yaml:"otl"`
}
